==> jonas-JONAS_4_6_4.tar.gz: jonas-JONAS_4_6_4/jonas/src/org/objectweb/jonas/webapp/jonasadmin/joramplatform/EditJoramLocalServerAction.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JoramObjectName;
import org.objectweb.jonas.webapp.jonasadmin.JonasAdminJmx;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;

/**
 * @author Frederic MAISTRE
 * @author Adriana Danes
 */

public class EditJoramLocalServerAction extends EditJoramBaseAction {

//	--------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping pMapping, ActionForm pForm
            , HttpServletRequest pRequest, HttpServletResponse pResponse)
    throws IOException, ServletException {

        String id = pRequest.getParameter("id");

        // Get reference on EJB container service in order to determine dependencies
        // between the deployed EJBs and JMS destinations
        initRefs();

        // Force the node selected in tree
        m_WhereAreYou.selectNameNode(getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
                + "joramplatform"/* + WhereAreYou.NODE_SEPARATOR
                + "joramlocalserver"*/, true);

        try {
            ObjectName joramAdapterON = (ObjectName) JonasManagementRepr.queryNames(JoramObjectName.joramAdapter()).iterator().next();
            boolean isAdapterLoaded = JonasManagementRepr.isRegistered(joramAdapterON);
            ObjectName joramAdminON = JoramObjectName.joramAdmin();

            ArrayList destinationsArray = new ArrayList();
            Iterator destinationsList = ((List) JonasManagementRepr.getAttribute(joramAdminON, "Destinations")).iterator();
            for (; destinationsList.hasNext(); ) {
                String destinationString = (String) destinationsList.next();
                ItemDestination destinationItem = getDestinationItem(destinationString);
                ObjectName destOn = destinationItem.getOn();
                if (destOn != null) {
                    destinationsArray.add(destinationItem);
                    //printDestination(destinationItem);
                }
            }
            Iterator usersList= ((List) JonasManagementRepr.getAttribute(joramAdapterON, "LocalUsers")).iterator();
            for (; usersList.hasNext(); ) {
                String destinationString = (String) usersList.next();
            }

            Collections.sort(destinationsArray, new ItemDestinationByName());
            m_Session.setAttribute("destinations", destinationsArray);
        } catch (Throwable t) {
            return (treatError(t, pMapping, pRequest));
        }

        // Forward to the jsp.
        return (pMapping.findForward("JoramLocalDestinations"));
    }

}

==> jonas-JONAS_4_10_4.tar.gz: jonas-JONAS_4_10_4/jonas/src/org/objectweb/jonas/webapp/jonasadmin/joramplatform/EditJoramLocalServerAction.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JoramObjectName;
import org.objectweb.jonas.webapp.jonasadmin.JonasAdminJmx;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;

/**
 * @author Frederic MAISTRE
 * @author Adriana Danes
 */

public class EditJoramLocalServerAction extends EditJoramBaseAction {

//	--------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping pMapping, ActionForm pForm
            , HttpServletRequest pRequest, HttpServletResponse pResponse)
    throws IOException, ServletException {

        // Current JOnAS server
        String serverName =  m_WhereAreYou.getCurrentJonasServerName();

        String id = pRequest.getParameter("id");

        // Get reference on EJB container service in order to determine dependencies
        // between the deployed EJBs and JMS destinations
        initRefs(serverName);

        // Force the node selected in tree
        m_WhereAreYou.selectNameNode(getTreeBranchName(DEPTH_DOMAIN) + WhereAreYou.NODE_SEPARATOR
                + "joramplatform"/* + WhereAreYou.NODE_SEPARATOR
                + "joramlocalserver"*/, true);

        try {
            ObjectName joramAdapterON = JoramObjectName.joramAdapter();
            boolean isAdapterLoaded = JonasManagementRepr.isRegistered(joramAdapterON, serverName);
            //ObjectName joramAdminON = JoramObjectName.joramAdmin();

            ArrayList destinationsArray = new ArrayList();
            Iterator destinationsList = ((List) JonasManagementRepr.getAttribute(joramAdapterON, "Destinations", serverName)).iterator();
            for (; destinationsList.hasNext(); ) {
                String destinationString = (String) destinationsList.next();
                ItemDestination destinationItem = getDestinationItem(destinationString, serverName);
                ObjectName destOn = destinationItem.getOn();
                if (destOn != null) {
                    destinationsArray.add(destinationItem);
                    //printDestination(destinationItem);
                }
            }
            Iterator usersList= ((List) JonasManagementRepr.getAttribute(joramAdapterON, "Users", serverName)).iterator();
            for (; usersList.hasNext(); ) {
                String destinationString = (String) usersList.next();
            }

            Collections.sort(destinationsArray, new ItemDestinationByName());
            m_Session.setAttribute("destinations", destinationsArray);
        } catch (Throwable t) {
            return (treatError(t, pMapping, pRequest));
        }

        // Forward to the jsp.
        return (pMapping.findForward("JoramLocalDestinations"));
    }

}
